@@ -8,9 +8,6 @@ from pymlconf.errors import ConfigurationNotInitializedError, \
 class TestDiferredRoot:
 
     def test_deferred_config_manager(self):
-        context = dict(
-            c=3
-        )
         config = '''
             a: 1
             b:
@@ -21,18 +18,18 @@ class TestDiferredRoot:
         with pytest.raises(ConfigurationNotInitializedError):
             root.attr
 
-        root.initialize(config, context)
+        root.initialize(config)
 
         with pytest.raises(ConfigurationAlreadyInitializedError):
             root.initialize(config)
 
         root.merge('''
-            c: %(c)s
+            foo: bar
         ''')
 
         assert root.a == 1
         assert root.b == [1]
-        assert root.c == 3
+        assert root.foo == 'bar'
 
         root.d = [1, 2]
         assert [1, 2] == root.d
